# Generated by Django 3.0.9 on 2021-10-18 14:36

from django.conf import settings
import django.contrib.postgres.fields
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('tmssapp', '0006_subtask_obsolete_since'),
    ]

    operations = [
        migrations.CreateModel(
            name='SystemEvent',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(blank=True, default='', help_text='A longer description of this object.', max_length=255)),
                ('start', models.DateTimeField(help_text='When this event started.')),
                ('stop', models.DateTimeField(help_text='When this event stopped (NULLable).', null=True)),
                ('notes', models.CharField(help_text='Any additional information', max_length=255, null=True)),
                ('affected_hardware_doc', django.contrib.postgres.fields.jsonb.JSONField(help_text='Properties of this event, e.g. station list and other hardware affected')),
                ('jira_url', models.CharField(help_text='Link to JIRA issue (if any)', max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SystemEventSeverity',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SystemEventStatus',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SystemEventSubtype',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SystemEventTemplate',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=128), blank=True, default=list, help_text='User-defined search keywords for object.', size=8)),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Moment of object creation.')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Moment of last object update.')),
                ('name', models.CharField(help_text='Human-readable name of this object.', max_length=128)),
                ('description', models.CharField(blank=True, default='', help_text='A longer description of this object.', max_length=255)),
                ('version', models.IntegerField(editable=False, help_text='Version of this template (with respect to other templates of the same name)')),
                ('schema', django.contrib.postgres.fields.jsonb.JSONField(help_text='Schema for the configurable parameters needed to use this template.')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SystemEventType',
            fields=[
                ('value', models.CharField(max_length=128, primary_key=True, serialize=False, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddConstraint(
            model_name='systemeventtemplate',
            constraint=models.UniqueConstraint(fields=('name', 'version'), name='systemeventtemplate_unique_name_version'),
        ),
        migrations.AddField(
            model_name='systemevent',
            name='affected_hardware_template',
            field=models.ForeignKey(help_text='Template for the affected_hardware_doc.', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SystemEventTemplate'),
        ),
        migrations.AddField(
            model_name='systemevent',
            name='affected_tasks',
            field=models.ManyToManyField(blank=True, help_text='The task blueprints that are affected by this issue', related_name='system_events', to='tmssapp.TaskBlueprint'),
        ),
        migrations.AddField(
            model_name='systemevent',
            name='created_by',
            field=models.ForeignKey(help_text='User who created this entry.', on_delete=django.db.models.deletion.PROTECT, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='systemevent',
            name='issue_subtype',
            field=models.ForeignKey(help_text='The subtype that classifies this issue', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SystemEventSubtype'),
        ),
        migrations.AddField(
            model_name='systemevent',
            name='issue_type',
            field=models.ForeignKey(help_text='The main type that classifies this issue', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SystemEventType'),
        ),
        migrations.AddField(
            model_name='systemevent',
            name='severity',
            field=models.ForeignKey(help_text='The subtype that classifies this issue', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SystemEventSeverity'),
        ),
        migrations.AddField(
            model_name='systemevent',
            name='status',
            field=models.ForeignKey(help_text='The current status of this issue', on_delete=django.db.models.deletion.PROTECT, to='tmssapp.SystemEventStatus'),
        ),
    ]
